@@ -1,7 +1,7 @@
 
 package OODoc;
 use vars '$VERSION';
-$VERSION = '0.10';
+$VERSION = '0.90';
 use base 'OODoc::Object';
 
 use strict;
@@ -42,6 +42,7 @@ sub init($)
         {   my $v = IO::File->new($fn, 'r')
                or die "ERROR: Cannot read version from file $fn: $!\n";
             $version = $v->getline;
+            $version = $1 if $version =~ m/(\d+\.[\d\.]+)/;
             chomp $version;
         }
     }
@@ -117,6 +118,7 @@ sub processFiles(@)
         {   my $v = IO::File->new($fn, "r")
                 or die "ERROR: Cannot read version from $fn: $!";
             $version = $v->getline;
+            $version = $1 if $version =~ m/(\d+\.[\d\.]+)/;
             chomp $version;
         }
         elsif($version = $self->version) { ; }
@@ -261,11 +263,14 @@ sub getPackageRelations()
 
     #
     # load all distributions (which are not loaded yet)
-    # simply ignore all errors.
+    #
 
     foreach my $manual (@manuals)
     {    next if $manual->isPurePod;
          eval "require $manual";
+         if($@ && $@ !~ /Can't locate/)
+         {   die "$@";
+         }
     }
 
     foreach my $manual (@manuals)
