@@ -1,7 +1,7 @@
 
 package OODoc::Format::Html;
 use vars '$VERSION';
-$VERSION = '0.10';
+$VERSION = '0.90';
 use base 'OODoc::Format';
 
 use strict;
@@ -730,7 +730,7 @@ sub templateInheritance(@)
     return '' unless length $output;
 
     for($output)
-    {   s#<pre>\n*(.*)</pre>\n*#$1#s;            # over-eager cleanup
+    {   s#<pre>\s*(.*?)</pre>\n*#\n$1#gs;   # over-eager cleanup
         s#^( +)#'&nbsp;' x length($1)#gme;
         s#$#<br />#gm;
     }
